@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -37,12 +37,15 @@ extern "C" {
 #endif
 
 #if (MAGICKCORE_QUANTUM_DEPTH == 8)
-#define MagickEpsilon  1.0e-6
-#define MagickHuge     1.0e6
+#define MagickEpsilon  ((MagickRealType) 1.0e-7)
 #define MaxColormapSize  256UL
 #define MaxMap  255UL
 
+#if defined __arm__ || defined __thumb__
+typedef float MagickRealType;
+#else
 typedef double MagickRealType;
+#endif
 #if defined(MAGICKCORE_HDRI_SUPPORT)
 typedef float Quantum;
 #define QuantumRange  255.0
@@ -53,12 +56,15 @@ typedef unsigned char Quantum;
 #define QuantumFormat  "%u"
 #endif
 #elif (MAGICKCORE_QUANTUM_DEPTH == 16)
-#define MagickEpsilon  1.0e-10
-#define MagickHuge     1.0e12
+#define MagickEpsilon  ((MagickRealType) 1.0e-16)
 #define MaxColormapSize  65536UL
 #define MaxMap  65535UL
 
+#if defined __arm__ || defined __thumb__
+typedef float MagickRealType;
+#else
 typedef double MagickRealType;
+#endif
 #if defined(MAGICKCORE_HDRI_SUPPORT)
 typedef float Quantum;
 #define QuantumRange  65535.0
@@ -69,8 +75,7 @@ typedef unsigned short Quantum;
 #define QuantumFormat  "%u"
 #endif
 #elif (MAGICKCORE_QUANTUM_DEPTH == 32)
-#define MagickEpsilon  1.0e-10
-#define MagickHuge     1.0e12
+#define MagickEpsilon  ((MagickRealType) 1.0e-16)
 #define MaxColormapSize  65536UL
 #define MaxMap  65535UL
 
@@ -85,8 +90,7 @@ typedef unsigned int Quantum;
 #define QuantumFormat  "%u"
 #endif
 #elif (MAGICKCORE_QUANTUM_DEPTH == 64) && defined(MAGICKCORE_HAVE_LONG_DOUBLE_WIDER)
-#define MagickEpsilon  1.0e-10
-#define MagickHuge     1.0e12
+#define MagickEpsilon  ((MagickRealType) 1.0e-16)
 #define MaxColormapSize  65536UL
 #define MaxMap  65535UL
 
@@ -99,6 +103,7 @@ typedef double Quantum;
 # error "MAGICKCORE_QUANTUM_DEPTH must be one of 8, 16, 32, or 64"
 #endif
 #endif
+#define MagickHuge  ((MagickRealType) 1.0/MagickEpsilon)
 
 /*
   Typedef declarations.
@@ -123,6 +128,12 @@ typedef unsigned __int64 MagickSizeType;
 #define MagickSizeFormat  "I64u"
 #endif
 
+#if QuantumDepth > 16
+  typedef double SignedQuantum;
+#else
+  typedef ssize_t SignedQuantum;
+#endif
+
 #if defined(_MSC_VER) && (_MSC_VER == 1200)
 typedef MagickOffsetType QuantumAny;
 #else
@@ -145,16 +156,19 @@ typedef enum
   YellowChannel = 0x0004,
   AlphaChannel = 0x0008,
   OpacityChannel = 0x0008,
-  MatteChannel = 0x0008,  /* deprecated */
+  MatteChannel = 0x0008,     /* deprecated */
   BlackChannel = 0x0020,
   IndexChannel = 0x0020,
-  AllChannels = 0x002F,
-  /* special channel types */
+  CompositeChannels = 0x002F,
+  AllChannels = 0x7ffffff,
+  /*
+    Special purpose channel types.
+  */
   TrueAlphaChannel = 0x0040, /* extract actual alpha channel from opacity */
   RGBChannels = 0x0080,      /* set alpha from  grayscale mask in RGB */
   GrayChannels = 0x0080,
   SyncChannels = 0x0100,     /* channels should be modified equally */
-  DefaultChannels = ( (AllChannels | SyncChannels) &~ OpacityChannel)
+  DefaultChannels = ((AllChannels | SyncChannels) &~ OpacityChannel)
 } ChannelType;
 
 typedef enum
