@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -336,8 +336,8 @@ extern "C" {
 #define FormatImageProperty  PrependMagickMethod(FormatImageProperty)
 #define FormatMagickCaption  PrependMagickMethod(FormatMagickCaption)
 #define FormatMagickSize  PrependMagickMethod(FormatMagickSize)
-#define FormatMagickStringList  PrependMagickMethod(FormatMagickStringList)
-#define FormatMagickString  PrependMagickMethod(FormatMagickString)
+#define FormatLocaleStringList  PrependMagickMethod(FormatLocaleStringList)
+#define FormatLocaleString  PrependMagickMethod(FormatLocaleString)
 #define FormatMagickTime  PrependMagickMethod(FormatMagickTime)
 #define FormatStringList  PrependMagickMethod(FormatStringList)
 #define FormatString  PrependMagickMethod(FormatString)
@@ -493,7 +493,7 @@ extern "C" {
 #define GetMagickInfo  PrependMagickMethod(GetMagickInfo)
 #define GetMagickList  PrependMagickMethod(GetMagickList)
 #define GetMagickMemoryMethods  PrependMagickMethod(GetMagickMemoryMethods)
-#define GetMagickOptions  PrependMagickMethod(GetMagickOptions)
+#define GetCommandOptions  PrependMagickMethod(GetCommandOptions)
 #define GetMagickPackageName  PrependMagickMethod(GetMagickPackageName)
 #define GetMagickPageSize  PrependMagickMethod(GetMagickPageSize)
 #define GetMagickPixelPacket  PrependMagickMethod(GetMagickPixelPacket)
@@ -667,7 +667,7 @@ extern "C" {
 #define IsMagickColorSimilar  PrependMagickMethod(IsMagickColorSimilar)
 #define IsMagickConflict  PrependMagickMethod(IsMagickConflict)
 #define IsMagickInstantiated  PrependMagickMethod(IsMagickInstantiated)
-#define IsMagickOption  PrependMagickMethod(IsMagickOption)
+#define IsCommandOption  PrependMagickMethod(IsCommandOption)
 #define IsMagickTrue  PrependMagickMethod(IsMagickTrue)
 #define IsMonochromeImage  PrependMagickMethod(IsMonochromeImage)
 #define IsOpacitySimilar  PrependMagickMethod(IsOpacitySimilar)
@@ -703,7 +703,7 @@ extern "C" {
 #define ListLogInfo  PrependMagickMethod(ListLogInfo)
 #define ListMagicInfo  PrependMagickMethod(ListMagicInfo)
 #define ListMagickInfo  PrependMagickMethod(ListMagickInfo)
-#define ListMagickOptions  PrependMagickMethod(ListMagickOptions)
+#define ListCommandOptions  PrependMagickMethod(ListCommandOptions)
 #define ListMagickResourceInfo  PrependMagickMethod(ListMagickResourceInfo)
 #define ListMimeInfo  PrependMagickMethod(ListMimeInfo)
 #define ListModuleInfo  PrependMagickMethod(ListModuleInfo)
@@ -738,7 +738,7 @@ extern "C" {
 #define MagickGetThreadValue  PrependMagickMethod(MagickGetThreadValue)
 #define MagickIncarnate  PrependMagickMethod(MagickIncarnate)
 #define MagickMonitor  PrependMagickMethod(MagickMonitor)
-#define MagickOptionToMnemonic  PrependMagickMethod(MagickOptionToMnemonic)
+#define CommandOptionToMnemonic  PrependMagickMethod(CommandOptionToMnemonic)
 #define MagickSetThreadValue  PrependMagickMethod(MagickSetThreadValue)
 #define MagickToMime  PrependMagickMethod(MagickToMime)
 #define MagickWarning  PrependMagickMethod(MagickWarning)
@@ -802,7 +802,7 @@ extern "C" {
 #define ParseGeometry  PrependMagickMethod(ParseGeometry)
 #define ParseGravityGeometry  PrependMagickMethod(ParseGravityGeometry)
 #define ParseImageGeometry  PrependMagickMethod(ParseImageGeometry)
-#define ParseMagickOption  PrependMagickMethod(ParseMagickOption)
+#define ParseCommandOption  PrependMagickMethod(ParseCommandOption)
 #define ParseMetaGeometry  PrependMagickMethod(ParseMetaGeometry)
 #define ParsePageGeometry  PrependMagickMethod(ParsePageGeometry)
 #define ParseRegionGeometry  PrependMagickMethod(ParseRegionGeometry)
@@ -838,7 +838,7 @@ extern "C" {
 #define QueryColorname  PrependMagickMethod(QueryColorname)
 #define QueryMagickColorname  PrependMagickMethod(QueryMagickColorname)
 #define QueryMagickColor  PrependMagickMethod(QueryMagickColor)
-#define QueueAuthenticNexus  PrependMagickMethod(QueueAuthenticNexus)
+#define QueueAuthenticPixelCacheNexus  PrependMagickMethod(QueueAuthenticPixelCacheNexus)
 #define QueueAuthenticPixels  PrependMagickMethod(QueueAuthenticPixels)
 #define QueueCacheViewAuthenticPixels  PrependMagickMethod(QueueCacheViewAuthenticPixels)
 #define RadialBlurImageChannel  PrependMagickMethod(RadialBlurImageChannel)
@@ -1035,7 +1035,7 @@ extern "C" {
 #define SampleImage  PrependMagickMethod(SampleImage)
 #define ScaleImage  PrependMagickMethod(ScaleImage)
 #define ScaleResampleFilter  PrependMagickMethod(ScaleResampleFilter)
-#define SeedPseudoRandomGenerator  PrependMagickMethod(SeedPseudoRandomGenerator)
+#define SetRandomSecretKey  PrependMagickMethod(SetRandomSecretKey)
 #define SeekBlob  PrependMagickMethod(SeekBlob)
 #define SegmentImage  PrependMagickMethod(SegmentImage)
 #define SelectiveBlurImageChannel  PrependMagickMethod(SelectiveBlurImageChannel)
