@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -26,15 +26,16 @@ extern "C" {
   Define declarations.
 */
 #define MagickPackageName "ImageMagick"
-#define MagickCopyright  "Copyright (C) 1999-2011 ImageMagick Studio LLC"
-#define MagickLibVersion  0x666
-#define MagickLibVersionText  "6.6.6"
-#define MagickLibVersionNumber  4,0,1
-#define MagickLibAddendum  "-10"
-#define MagickLibInterface  4
-#define MagickLibMinInterface  4
-#define MagickReleaseDate  "2011-08-04"
-#define MagickChangeDate   "20100101"
+#define MagickCopyright  "Copyright (C) 1999-2012 ImageMagick Studio LLC"
+#define MagickSVNRevision  "8219"
+#define MagickLibVersion  0x677
+#define MagickLibVersionText  "6.7.7"
+#define MagickLibVersionNumber  5,0,0
+#define MagickLibAddendum  "-7"
+#define MagickLibInterface  5
+#define MagickLibMinInterface  5
+#define MagickReleaseDate  "2014-08-01"
+#define MagickChangeDate   "20120606"
 #define MagickAuthoritativeURL  "http://www.imagemagick.org"
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
 #define MagickOpenMPFeature  "OpenMP "
@@ -51,7 +52,12 @@ extern "C" {
 #else
 #define MagickHDRIFeature  " "
 #endif
-#define MagickFeatures MagickOpenMPFeature MagickOpenCLFeature MagickHDRIFeature
+#if defined(MAGICKCORE_ZERO_CONFIGURATION_SUPPORT)
+#define MagickZeroConfigurationFeature  "Zero-Configuration "
+#else
+#define MagickZeroConfigurationFeature  " "
+#endif
+#define MagickFeatures MagickOpenMPFeature MagickOpenCLFeature MagickHDRIFeature MagickZeroConfigurationFeature
 #define MagickHomeURL  "file:///usr/local/share/doc/ImageMagick/index.html"
 #if (MAGICKCORE_QUANTUM_DEPTH == 8)
 #define MagickQuantumDepth  "Q8"
