@@ -1,12 +1,12 @@
 /*
-  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
-  
+
   You may not use this file except in compliance with the License.
   obtain a copy of the License at
-  
+
     http://www.imagemagick.org/script/license.php
-  
+
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -23,6 +23,9 @@
 extern "C" {
 #endif
 
+extern WandExport ChannelFeatures
+  *MagickGetImageChannelFeatures(MagickWand *,const size_t);
+
 extern WandExport ChannelStatistics
   *MagickGetImageChannelStatistics(MagickWand *);
 
@@ -32,12 +35,12 @@ extern WandExport char
   *MagickGetImageSignature(MagickWand *),
   *MagickIdentifyImage(MagickWand *);
 
-extern WandExport CompositeOperator
-  MagickGetImageCompose(MagickWand *);
-
 extern WandExport ColorspaceType
   MagickGetImageColorspace(MagickWand *);
 
+extern WandExport CompositeOperator
+  MagickGetImageCompose(MagickWand *);
+
 extern WandExport CompressionType
   MagickGetImageCompression(MagickWand *);
 
@@ -47,9 +50,13 @@ extern WandExport DisposeType
 extern WandExport double
   *MagickGetImageChannelDistortions(MagickWand *,const MagickWand *,
     const MetricType),
+  MagickGetImageFuzz(MagickWand *),
   MagickGetImageGamma(MagickWand *),
   MagickGetImageTotalInkDensity(MagickWand *);
 
+extern WandExport EndianType
+  MagickGetImageEndian(MagickWand *);
+
 extern WandExport GravityType
   MagickGetImageGravity(MagickWand *);
 
@@ -70,13 +77,12 @@ extern WandExport MagickBooleanType
   MagickAdaptiveBlurImage(MagickWand *,const double,const double),
   MagickAdaptiveBlurImageChannel(MagickWand *,const ChannelType,const double,
     const double),
-  MagickAdaptiveResizeImage(MagickWand *,const unsigned long,
-    const unsigned long),
+  MagickAdaptiveResizeImage(MagickWand *,const size_t,const size_t),
   MagickAdaptiveSharpenImage(MagickWand *,const double,const double),
   MagickAdaptiveSharpenImageChannel(MagickWand *,const ChannelType,const double,
     const double),
-  MagickAdaptiveThresholdImage(MagickWand *,const unsigned long,
-    const unsigned long,const long),
+  MagickAdaptiveThresholdImage(MagickWand *,const size_t,const size_t,
+    const ssize_t),
   MagickAddImage(MagickWand *,const MagickWand *),
   MagickAddNoiseImage(MagickWand *,const NoiseType),
   MagickAddNoiseImageChannel(MagickWand *,const ChannelType,const NoiseType),
@@ -84,42 +90,55 @@ extern WandExport MagickBooleanType
   MagickAnnotateImage(MagickWand *,const DrawingWand *,const double,
     const double,const double,const char *),
   MagickAnimateImages(MagickWand *,const char *),
+  MagickAutoGammaImage(MagickWand *),
+  MagickAutoGammaImageChannel(MagickWand *,const ChannelType),
+  MagickAutoLevelImage(MagickWand *),
+  MagickAutoLevelImageChannel(MagickWand *,const ChannelType),
   MagickBlackThresholdImage(MagickWand *,const PixelWand *),
+  MagickBlueShiftImage(MagickWand *,const double),
   MagickBlurImage(MagickWand *,const double,const double),
   MagickBlurImageChannel(MagickWand *,const ChannelType,const double,
     const double),
-  MagickBorderImage(MagickWand *,const PixelWand *,const unsigned long,
-    const unsigned long),
+  MagickBorderImage(MagickWand *,const PixelWand *,const size_t,const size_t),
+  MagickBrightnessContrastImage(MagickWand *,const double,const double),
+  MagickBrightnessContrastImageChannel(MagickWand *,const ChannelType,
+    const double,const double),
   MagickCharcoalImage(MagickWand *,const double,const double),
-  MagickChopImage(MagickWand *,const unsigned long,const unsigned long,
-    const long,const long),
+  MagickChopImage(MagickWand *,const size_t,const size_t,const ssize_t,
+    const ssize_t),
+  MagickClampImage(MagickWand *),
+  MagickClampImageChannel(MagickWand *,const ChannelType),
   MagickClipImage(MagickWand *),
   MagickClipImagePath(MagickWand *,const char *,const MagickBooleanType),
   MagickClutImage(MagickWand *,const MagickWand *),
   MagickClutImageChannel(MagickWand *,const ChannelType,const MagickWand *),
+  MagickColorDecisionListImage(MagickWand *,const char *),
   MagickColorizeImage(MagickWand *,const PixelWand *,const PixelWand *),
+  MagickColorMatrixImage(MagickWand *,const KernelInfo *),
   MagickCommentImage(MagickWand *,const char *),
   MagickCompositeImage(MagickWand *,const MagickWand *,const CompositeOperator,
-    const long,const long),
-  MagickCompositeImageChannel(MagickWand *,const ChannelType,const MagickWand *,    const CompositeOperator,const long,const long),
-  MagickConstituteImage(MagickWand *,const unsigned long,const unsigned long,
-    const char *,const StorageType,const void *),
+    const ssize_t,const ssize_t),
+  MagickCompositeLayers(MagickWand *,const MagickWand *,const CompositeOperator,
+    const ssize_t,const ssize_t),
+  MagickCompositeImageChannel(MagickWand *,const ChannelType,const MagickWand *,    const CompositeOperator,const ssize_t,const ssize_t),
+  MagickConstituteImage(MagickWand *,const size_t,const size_t,const char *,
+    const StorageType,const void *),
   MagickContrastImage(MagickWand *,const MagickBooleanType),
   MagickContrastStretchImage(MagickWand *,const double,const double),
   MagickContrastStretchImageChannel(MagickWand *,const ChannelType,const double,
     const double),
-  MagickConvolveImage(MagickWand *,const unsigned long,const double *),
-  MagickConvolveImageChannel(MagickWand *,const ChannelType,const unsigned long,
+  MagickConvolveImage(MagickWand *,const size_t,const double *),
+  MagickConvolveImageChannel(MagickWand *,const ChannelType,const size_t,
     const double *),
-  MagickCropImage(MagickWand *,const unsigned long,const unsigned long,
-    const long,const long),
-  MagickCycleColormapImage(MagickWand *,const long),
+  MagickCropImage(MagickWand *,const size_t,const size_t,const ssize_t,
+    const ssize_t),
+  MagickCycleColormapImage(MagickWand *,const ssize_t),
   MagickDecipherImage(MagickWand *,const char *),
   MagickDeskewImage(MagickWand *,const double),
   MagickDespeckleImage(MagickWand *),
   MagickDisplayImage(MagickWand *,const char *),
   MagickDisplayImages(MagickWand *,const char *),
-  MagickDistortImage(MagickWand *,const DistortImageMethod,const unsigned long,
+  MagickDistortImage(MagickWand *,const DistortImageMethod,const size_t,
     const double *,const MagickBooleanType),
   MagickDrawImage(MagickWand *,const DrawingWand *),
   MagickEdgeImage(MagickWand *,const double),
@@ -131,15 +150,24 @@ extern WandExport MagickBooleanType
   MagickEvaluateImage(MagickWand *,const MagickEvaluateOperator,const double),
   MagickEvaluateImageChannel(MagickWand *,const ChannelType,
     const MagickEvaluateOperator,const double),
-  MagickExtentImage(MagickWand *,const unsigned long,const unsigned long,
-    const long,const long),
+  MagickExportImagePixels(MagickWand *,const ssize_t,const ssize_t,
+    const size_t,const size_t,const char *,const StorageType,void *),
+  MagickExtentImage(MagickWand *,const size_t,const size_t,const ssize_t,
+    const ssize_t),
+  MagickFilterImage(MagickWand *,const KernelInfo *),
+  MagickFilterImageChannel(MagickWand *,const ChannelType,const KernelInfo *),
   MagickFlipImage(MagickWand *),
   MagickFloodfillPaintImage(MagickWand *,const ChannelType,const PixelWand *,
-    const double,const PixelWand *,const long,const long,
+    const double,const PixelWand *,const ssize_t,const ssize_t,
     const MagickBooleanType),
   MagickFlopImage(MagickWand *),
-  MagickFrameImage(MagickWand *,const PixelWand *,const unsigned long,
-    const unsigned long,const long,const long),
+  MagickForwardFourierTransformImage(MagickWand *,const MagickBooleanType),
+  MagickFrameImage(MagickWand *,const PixelWand *,const size_t,const size_t,
+    const ssize_t,const ssize_t),
+  MagickFunctionImage(MagickWand *,const MagickFunction,const size_t,
+    const double *),
+  MagickFunctionImageChannel(MagickWand *,const ChannelType,
+    const MagickFunction,const size_t,const double *),
   MagickGammaImage(MagickWand *,const double),
   MagickGammaImageChannel(MagickWand *,const ChannelType,const double),
   MagickGaussianBlurImage(MagickWand *,const double,const double),
@@ -150,46 +178,57 @@ extern WandExport MagickBooleanType
   MagickGetImageBluePrimary(MagickWand *,double *,double *),
   MagickGetImageBorderColor(MagickWand *,PixelWand *),
   MagickGetImageChannelDistortion(MagickWand *,const MagickWand *,
-    const ChannelType, const MetricType,double *),
-  MagickGetImageDistortion(MagickWand *,const MagickWand *,const MetricType,
+    const ChannelType,const MetricType,double *),
+  MagickGetImageChannelKurtosis(MagickWand *,const ChannelType,double *,
     double *),
   MagickGetImageChannelMean(MagickWand *,const ChannelType,double *,double *),
   MagickGetImageChannelRange(MagickWand *,const ChannelType,double *,double *),
-  MagickGetImageColormapColor(MagickWand *,const unsigned long,PixelWand *),
+  MagickGetImageColormapColor(MagickWand *,const size_t,PixelWand *),
+  MagickGetImageDistortion(MagickWand *,const MagickWand *,const MetricType,
+    double *),
   MagickGetImageGreenPrimary(MagickWand *,double *,double *),
   MagickGetImageMatteColor(MagickWand *,PixelWand *),
   MagickGetImageLength(MagickWand *,MagickSizeType *),
-  MagickGetImagePage(MagickWand *,unsigned long *,unsigned long *,long *,
-    long *),
-  MagickGetImagePixelColor(MagickWand *,const long,const long,PixelWand *),
-  MagickGetAuthenticPixels(MagickWand *,const long,const long,const unsigned long,
-    const unsigned long,const char *,const StorageType,void *),
+  MagickGetImagePage(MagickWand *,size_t *,size_t *,ssize_t *,
+    ssize_t *),
+  MagickGetImagePixelColor(MagickWand *,const ssize_t,const ssize_t,
+    PixelWand *),
   MagickGetImageRange(MagickWand *,double *,double *),
   MagickGetImageRedPrimary(MagickWand *,double *,double *),
   MagickGetImageResolution(MagickWand *,double *,double *),
   MagickGetImageWhitePoint(MagickWand *,double *,double *),
+  MagickHaldClutImage(MagickWand *,const MagickWand *),
+  MagickHaldClutImageChannel(MagickWand *,const ChannelType,const MagickWand *),
   MagickHasNextImage(MagickWand *),
   MagickHasPreviousImage(MagickWand *),
   MagickImplodeImage(MagickWand *,const double),
+  MagickImportImagePixels(MagickWand *,const ssize_t,const ssize_t,const size_t,
+    const size_t,const char *,const StorageType,const void *),
+  MagickInverseFourierTransformImage(MagickWand *,MagickWand *,
+    const MagickBooleanType),
   MagickLabelImage(MagickWand *,const char *),
   MagickLevelImage(MagickWand *,const double,const double,const double),
   MagickLevelImageChannel(MagickWand *,const ChannelType,const double,
     const double,const double),
   MagickLinearStretchImage(MagickWand *,const double,const double),
-  MagickLiquidRescaleImage(MagickWand *,const unsigned long,const unsigned long,
-    const double,const double),
+  MagickLiquidRescaleImage(MagickWand *,const size_t,const size_t,const double,
+    const double),
   MagickMagnifyImage(MagickWand *),
   MagickMedianFilterImage(MagickWand *,const double),
   MagickMinifyImage(MagickWand *),
+  MagickModeImage(MagickWand *,const double),
   MagickModulateImage(MagickWand *,const double,const double,const double),
+  MagickMorphologyImage(MagickWand *,MorphologyMethod,const ssize_t,
+    KernelInfo *),
+  MagickMorphologyImageChannel(MagickWand *,const ChannelType,MorphologyMethod,
+    const ssize_t,KernelInfo *),
   MagickMotionBlurImage(MagickWand *,const double,const double,const double),
   MagickMotionBlurImageChannel(MagickWand *,const ChannelType,const double,
     const double,const double),
   MagickNegateImage(MagickWand *,const MagickBooleanType),
   MagickNegateImageChannel(MagickWand *,const ChannelType,
     const MagickBooleanType),
-  MagickNewImage(MagickWand *,const unsigned long,const unsigned long,
-    const PixelWand *),
+  MagickNewImage(MagickWand *,const size_t,const size_t,const PixelWand *),
   MagickNextImage(MagickWand *),
   MagickNormalizeImage(MagickWand *),
   MagickNormalizeImageChannel(MagickWand *,const ChannelType),
@@ -207,37 +246,39 @@ extern WandExport MagickBooleanType
   MagickPingImageBlob(MagickWand *,const void *,const size_t),
   MagickPingImageFile(MagickWand *,FILE *),
   MagickPolaroidImage(MagickWand *,const DrawingWand *,const double),
-  MagickPosterizeImage(MagickWand *,const unsigned long,
-    const MagickBooleanType),
+  MagickPosterizeImage(MagickWand *,const size_t,const MagickBooleanType),
   MagickPreviousImage(MagickWand *),
-  MagickQuantizeImage(MagickWand *,const unsigned long,const ColorspaceType,
-    const unsigned long,const MagickBooleanType,const MagickBooleanType),
-  MagickQuantizeImages(MagickWand *,const unsigned long,const ColorspaceType,
-    const unsigned long,const MagickBooleanType,const MagickBooleanType),
+  MagickQuantizeImage(MagickWand *,const size_t,const ColorspaceType,
+    const size_t,const MagickBooleanType,const MagickBooleanType),
+  MagickQuantizeImages(MagickWand *,const size_t,const ColorspaceType,
+    const size_t,const MagickBooleanType,const MagickBooleanType),
   MagickRadialBlurImage(MagickWand *,const double),
   MagickRadialBlurImageChannel(MagickWand *,const ChannelType,const double),
-  MagickRaiseImage(MagickWand *,const unsigned long,const unsigned long,
-    const long,const long,const MagickBooleanType),
+  MagickRaiseImage(MagickWand *,const size_t,const size_t,const ssize_t,
+    const ssize_t,const MagickBooleanType),
   MagickRandomThresholdImage(MagickWand *,const double,const double),
   MagickRandomThresholdImageChannel(MagickWand *,const ChannelType,const double,
     const double),
   MagickReadImage(MagickWand *,const char *),
   MagickReadImageBlob(MagickWand *,const void *,const size_t),
   MagickReadImageFile(MagickWand *,FILE *),
-  MagickRecolorImage(MagickWand *,const unsigned long,const double *),
   MagickReduceNoiseImage(MagickWand *,const double),
   MagickRemapImage(MagickWand *,const MagickWand *,const DitherMethod),
   MagickRemoveImage(MagickWand *),
   MagickResampleImage(MagickWand *,const double,const double,const FilterTypes,
     const double),
-  MagickResizeImage(MagickWand *,const unsigned long,const unsigned long,
-    const FilterTypes,const double),
-  MagickRollImage(MagickWand *,const long,const long),
+  MagickResetImagePage(MagickWand *,const char *),
+  MagickResizeImage(MagickWand *,const size_t,const size_t,const FilterTypes,
+    const double),
+  MagickRollImage(MagickWand *,const ssize_t,const ssize_t),
   MagickRotateImage(MagickWand *,const PixelWand *,const double),
-  MagickSampleImage(MagickWand *,const unsigned long,const unsigned long),
-  MagickScaleImage(MagickWand *,const unsigned long,const unsigned long),
+  MagickSampleImage(MagickWand *,const size_t,const size_t),
+  MagickScaleImage(MagickWand *,const size_t,const size_t),
   MagickSegmentImage(MagickWand *,const ColorspaceType,const MagickBooleanType,
     const double,const double),
+  MagickSelectiveBlurImage(MagickWand *,const double,const double,const double),
+  MagickSelectiveBlurImageChannel(MagickWand *,const ChannelType,const double,
+    const double,const double),
   MagickSeparateImageChannel(MagickWand *,const ChannelType),
   MagickSepiaToneImage(MagickWand *,const double),
   MagickSetImage(MagickWand *,const MagickWand *),
@@ -246,53 +287,51 @@ extern WandExport MagickBooleanType
   MagickSetImageBias(MagickWand *,const double),
   MagickSetImageBluePrimary(MagickWand *,const double,const double),
   MagickSetImageBorderColor(MagickWand *,const PixelWand *),
-  MagickSetImageChannelDepth(MagickWand *,const ChannelType,
-    const unsigned long),
+  MagickSetImageChannelDepth(MagickWand *,const ChannelType,const size_t),
   MagickSetImageClipMask(MagickWand *,const MagickWand *),
-  MagickSetImageColormapColor(MagickWand *,const unsigned long,
+  MagickSetImageColor(MagickWand *,const PixelWand *),
+  MagickSetImageColormapColor(MagickWand *,const size_t,
     const PixelWand *),
+  MagickSetImageColorspace(MagickWand *,const ColorspaceType),
   MagickSetImageCompose(MagickWand *,const CompositeOperator),
   MagickSetImageCompression(MagickWand *,const CompressionType),
-  MagickSetImageDelay(MagickWand *,const unsigned long),
-  MagickSetImageDepth(MagickWand *,const unsigned long),
+  MagickSetImageDelay(MagickWand *,const size_t),
+  MagickSetImageDepth(MagickWand *,const size_t),
   MagickSetImageDispose(MagickWand *,const DisposeType),
-  MagickSetImageColorspace(MagickWand *,const ColorspaceType),
-  MagickSetImageCompressionQuality(MagickWand *,const unsigned long),
-  MagickSetImageGreenPrimary(MagickWand *,const double,const double),
-  MagickSetImageGamma(MagickWand *,const double),
-  MagickSetImageExtent(MagickWand *,const unsigned long,const unsigned long),
+  MagickSetImageCompressionQuality(MagickWand *,const size_t),
+  MagickSetImageEndian(MagickWand *,const EndianType),
+  MagickSetImageExtent(MagickWand *,const size_t,const size_t),
   MagickSetImageFilename(MagickWand *,const char *),
-  MagickSetImageGravity(MagickWand *,const GravityType),
   MagickSetImageFormat(MagickWand *,const char *),
+  MagickSetImageFuzz(MagickWand *,const double),
+  MagickSetImageGamma(MagickWand *,const double),
+  MagickSetImageGravity(MagickWand *,const GravityType),
+  MagickSetImageGreenPrimary(MagickWand *,const double,const double),
   MagickSetImageInterlaceScheme(MagickWand *,const InterlaceType),
-  MagickSetImageInterpolateMethod(MagickWand *,
-    const InterpolatePixelMethod),
-  MagickSetImageIterations(MagickWand *,const unsigned long),
+  MagickSetImageInterpolateMethod(MagickWand *,const InterpolatePixelMethod),
+  MagickSetImageIterations(MagickWand *,const size_t),
   MagickSetImageMatte(MagickWand *,const MagickBooleanType),
   MagickSetImageMatteColor(MagickWand *,const PixelWand *),
   MagickSetImageOpacity(MagickWand *,const double),
   MagickSetImageOrientation(MagickWand *,const OrientationType),
-  MagickSetImagePage(MagickWand *,const unsigned long,const unsigned long,
-    const long,const long),
-  MagickResetImagePage(MagickWand *,const char *),
-  MagickQueueAuthenticPixels(MagickWand *,const long,const long,const unsigned long,
-    const unsigned long,const char *,const StorageType,const void *),
+  MagickSetImagePage(MagickWand *,const size_t,const size_t,const ssize_t,
+    const ssize_t),
   MagickSetImageRedPrimary(MagickWand *,const double,const double),
   MagickSetImageRenderingIntent(MagickWand *,const RenderingIntent),
   MagickSetImageResolution(MagickWand *,const double,const double),
-  MagickSetImageScene(MagickWand *,const unsigned long),
-  MagickSetImageTicksPerSecond(MagickWand *,const long),
+  MagickSetImageScene(MagickWand *,const size_t),
+  MagickSetImageTicksPerSecond(MagickWand *,const ssize_t),
   MagickSetImageType(MagickWand *,const ImageType),
   MagickSetImageUnits(MagickWand *,const ResolutionType),
   MagickSetImageWhitePoint(MagickWand *,const double,const double),
-  MagickShadeImage(MagickWand *,const MagickBooleanType,const double,const 
-    double),
-  MagickShadowImage(MagickWand *,const double,const double,const long,
-    const long),
+  MagickShadeImage(MagickWand *,const MagickBooleanType,const double,
+    const double),
+  MagickShadowImage(MagickWand *,const double,const double,const ssize_t,
+    const ssize_t),
   MagickSharpenImage(MagickWand *,const double,const double),
   MagickSharpenImageChannel(MagickWand *,const ChannelType,const double,
     const double),
-  MagickShaveImage(MagickWand *,const unsigned long,const unsigned long),
+  MagickShaveImage(MagickWand *,const size_t,const size_t),
   MagickShearImage(MagickWand *,const PixelWand *,const double,const double),
   MagickSigmoidalContrastImage(MagickWand *,const MagickBooleanType,
     const double,const double),
@@ -301,26 +340,31 @@ extern WandExport MagickBooleanType
   MagickSketchImage(MagickWand *,const double,const double,const double),
   MagickSolarizeImage(MagickWand *,const double),
   MagickSparseColorImage(MagickWand *,const ChannelType,const SparseColorMethod,
-    const unsigned long,const double *),
-  MagickSpliceImage(MagickWand *,const unsigned long,const unsigned long,
-    const long,const long),
+    const size_t,const double *),
+  MagickSpliceImage(MagickWand *,const size_t,const size_t,const ssize_t,
+    const ssize_t),
   MagickSpreadImage(MagickWand *,const double),
+  MagickStatisticImage(MagickWand *,const ChannelType,const StatisticType,
+    const size_t,const size_t),
+  MagickStatisticImageChannel(MagickWand *,const StatisticType,const size_t,
+    const size_t),
   MagickStripImage(MagickWand *),
   MagickSwirlImage(MagickWand *,const double),
   MagickTintImage(MagickWand *,const PixelWand *,const PixelWand *),
+  MagickTransformImageColorspace(MagickWand *,const ColorspaceType),
   MagickTransposeImage(MagickWand *),
   MagickTransverseImage(MagickWand *),
   MagickThresholdImage(MagickWand *,const double),
   MagickThresholdImageChannel(MagickWand *,const ChannelType,const double),
-  MagickThumbnailImage(MagickWand *,const unsigned long,const unsigned long),
+  MagickThumbnailImage(MagickWand *,const size_t,const size_t),
   MagickTrimImage(MagickWand *,const double),
   MagickUniqueImageColors(MagickWand *),
   MagickUnsharpMaskImage(MagickWand *,const double,const double,const double,
     const double),
   MagickUnsharpMaskImageChannel(MagickWand *,const ChannelType,const double,
     const double,const double,const double),
-  MagickVignetteImage(MagickWand *,const double,const double,
-    const long,const long),
+  MagickVignetteImage(MagickWand *,const double,const double,const ssize_t,
+    const ssize_t),
   MagickWaveImage(MagickWand *,const double,const double),
   MagickWhiteThresholdImage(MagickWand *,const PixelWand *),
   MagickWriteImage(MagickWand *,const char *),
@@ -334,7 +378,6 @@ WandExport MagickProgressMonitor
 
 extern WandExport MagickWand
   *MagickAppendImages(MagickWand *,const MagickBooleanType),
-  *MagickAverageImages(MagickWand *),
   *MagickCoalesceImages(MagickWand *),
   *MagickCombineImages(MagickWand *,const ChannelType),
   *MagickCompareImageChannels(MagickWand *,const MagickWand *,const ChannelType,
@@ -343,29 +386,32 @@ extern WandExport MagickWand
     double *),
   *MagickCompareImageLayers(MagickWand *,const ImageLayerMethod),
   *MagickDeconstructImages(MagickWand *),
+  *MagickEvaluateImages(MagickWand *,const MagickEvaluateOperator),
   *MagickFxImage(MagickWand *,const char *),
   *MagickFxImageChannel(MagickWand *,const ChannelType,const char *),
   *MagickGetImage(MagickWand *),
   *MagickGetImageClipMask(MagickWand *),
-  *MagickGetImageRegion(MagickWand *,const unsigned long,const unsigned long,
-    const long,const long),
+  *MagickGetImageRegion(MagickWand *,const size_t,const size_t,const ssize_t,
+    const ssize_t),
   *MagickMergeImageLayers(MagickWand *,const ImageLayerMethod),
-  *MagickMorphImages(MagickWand *,const unsigned long),
+  *MagickMorphImages(MagickWand *,const size_t),
   *MagickMontageImage(MagickWand *,const DrawingWand *,const char *,
     const char *,const MontageMode,const char *),
   *MagickOptimizeImageLayers(MagickWand *),
   *MagickPreviewImages(MagickWand *wand,const PreviewType),
-  *MagickSteganoImage(MagickWand *,const MagickWand *,const long),
+  *MagickSimilarityImage(MagickWand *,const MagickWand *,RectangleInfo *,
+    double *),
+  *MagickSmushImages(MagickWand *,const MagickBooleanType,const ssize_t),
+  *MagickSteganoImage(MagickWand *,const MagickWand *,const ssize_t),
   *MagickStereoImage(MagickWand *,const MagickWand *),
   *MagickTextureImage(MagickWand *,const MagickWand *),
-  *MagickTransformImage(MagickWand *,const char *,const char *),
-  *NewMagickWandFromImage(const Image *);
+  *MagickTransformImage(MagickWand *,const char *,const char *);
 
 extern WandExport OrientationType
   MagickGetImageOrientation(MagickWand *);
 
 extern WandExport PixelWand
-  **MagickGetImageHistogram(MagickWand *,unsigned long *);
+  **MagickGetImageHistogram(MagickWand *,size_t *);
 
 extern WandExport RenderingIntent
   MagickGetImageRenderingIntent(MagickWand *);
@@ -373,11 +419,7 @@ extern WandExport RenderingIntent
 extern WandExport ResolutionType
   MagickGetImageUnits(MagickWand *);
 
-extern WandExport unsigned char
-  *MagickGetImageBlob(MagickWand *,size_t *),
-  *MagickGetImagesBlob(MagickWand *,size_t *);
-
-extern WandExport unsigned long
+extern WandExport size_t
   MagickGetImageColors(MagickWand *),
   MagickGetImageCompressionQuality(MagickWand *),
   MagickGetImageDelay(MagickWand *),
@@ -390,8 +432,13 @@ extern WandExport unsigned long
   MagickGetImageWidth(MagickWand *),
   MagickGetNumberImages(MagickWand *);
 
+extern WandExport unsigned char
+  *MagickGetImageBlob(MagickWand *,size_t *),
+  *MagickGetImagesBlob(MagickWand *,size_t *);
+
 extern WandExport VirtualPixelMethod
-  MagickGetImageVirtualPixelMethod(MagickWand *);
+  MagickGetImageVirtualPixelMethod(MagickWand *),
+  MagickSetImageVirtualPixelMethod(MagickWand *,const VirtualPixelMethod);
 
 #if defined(__cplusplus) || defined(c_plusplus)
 }
